#
# spec file for package screenshot-tool
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name screenshot
Name:           screenshot-tool
Version:        0.1.4
Release:        bp154.1.66
Summary:        A simple screen capture tool
License:        GPL-3.0
Group:          Productivity/Graphics/Other
Url:            https://launchpad.net/screenshot-tool
Source:         https://launchpad.net/screenshot-tool/0.1.x/%{version}/+download/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  elementary-icon-theme
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(vapigen) >= 0.28.0
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
A simple screen capture tool made for elementary OS.

%lang_package

%prep
%setup -q

%build
%cmake \
    -DGSETTINGS_COMPILE=OFF \
    -DICON_UPDATE=OFF
make %{?_smp_mflags}

%install
%cmake_install

pushd %{buildroot}
for _icon in $(find -name \*.desktop* | xargs sed -n '/Icon/s/^.*\=//p'); do
    _icon=${_icon##*/}
    if ! find -name "$_icon" | grep -q .; then
        _icon=$(find %{_datadir}/icons -name "${_icon%.*}.svg" | sort | head -n1)
        install -Dm0644 \
            "$_icon" ".%{_datadir}/icons/hicolor/scalable/apps/${_icon##*/}"
    else
        echo "Found: $_icon"
        exit 1
    fi
done
popd

%suse_update_desktop_file -r -G Screenshot %{name} GTK Utility DesktopUtility
%fdupes %{buildroot}%{_datadir}/locale
%find_lang %{name}

%post
%icon_theme_cache_post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/accessories-screenshot.??g
%{_datadir}/glib-2.0/schemas/net.launchpad.screenshot.gschema.xml
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 0.1.4:
  * Update license headers (#45)
  * Get preview image at scale (#43)
  * New default folder to save screenshots (#46)
  * Remove about dialog and use Gtk.App (#44)
  * Update URLs in AppData (#42)
  * Create .gitignore (#40)
  * Create CODE_OF_CONDUCT.md (#39)
  * Remember main window position for reappearing window (#32)
* Tue Jul 11 2017 bwiedemann@suse.com
- Sort file lists to always install the same .svg size
  to fix build-compare (boo#1041090)
* Mon May  1 2017 avvissu@yandex.by
- Update to 0.1.3.1
* Sat Apr 22 2017 avvissu@yandex.by
- Update to 0.1.3:
  * Update and rename INSTALL to README.md (#18)
  * Also adds missing libcanberra dep
  * Launchpad automatic translations update.
  * Fix bug #1670010
  * Ensure screenshots are saved to correct directory when
    launched from Slingshot.
  * Implement non-interactive mode (fix bug 1665708)
  * AppData: remove spurious Unicode characters and fix
    indentation
  * Hide main window behind save dialog when app is launched from
    command
  * Show main window after window not found error
  * Replace colons with dots in screenshot's filename (lp#1663734)
  * Play shutter sound when screenshot is taken
* Sat Feb 11 2017 avvissu@yandex.by
- Update to 0.1.2:
  * Add "accessories-screenshot" icons and install to hicolor
  * Add releases data
  * SaveDialog.vala:
  * Use GObject-style construction
  * Update copyright header
  * Don't declare widgets outside of construct
  * Use Vala-style properties
  * Organize, Don't nest boxes
  * Don't crop window screenshots on HiDPI
  * ScreenshotWindow.vala:
  * Add elementary to copyright
  * Use GLib.Settings.bind
  * Remove unnecessary comments
  * Group all grid attach methods
  * Don't declare GNOME interface settings twice
  * Radiobuttons aren't used outside construct, so don't declare
    them outside of it
  * Code style
  * Fix the dimensions and placement of the mouse cursor for
    HiDPI displays
  * Account for the scaling factor when taking a screenshot of
    the whole screen (lp#1616530)
  * Quit on Ctrl + Q
- Spec file cleanup
* Fri Nov 25 2016 avvissu@yandex.by
- Update to 0.1.1:
  * Listen to structure events
  * update translation template
  * Add Copy to Clipboard save option
  * Don't overwrite files
  * Keep above & follow
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.1.0.2
- Fix: icon file not installed
- Spec file cleanup
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.1.0.1
- Spec file cleanup
* Sat Sep 26 2015 and.november@opensuse.org
- initial package for openSUSE
